==> cloudfoundry-client-5.6.0.RELEASE-sources.jar: org/cloudfoundry/client/v3/processes/HealthCheckType.java <==
/*
 * Copyright 2013-2021 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.cloudfoundry.client.v3.processes;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;

/**
 * The type of a {@link HealthCheck}
 */
public enum HealthCheckType {

    /**
     * An http health check
     */
    HTTP("http"),

    /**
     * No health check (deprecated, backwards compatibility only)
     */
    @Deprecated
    NONE("none"),

    /**
     * A port health check
     */
    PORT("port"),

    /**
     * A process health check
     */
    PROCESS("process");

    private final String value;

    HealthCheckType(String value) {
        this.value = value;
    }

    @JsonCreator
    public static HealthCheckType from(String s) {
        switch (s.toLowerCase()) {
            case "http":
                return HTTP;
            case "none":
                return NONE;
            case "port":
                return PORT;
            case "process":
                return PROCESS;
            default:
                throw new IllegalArgumentException(String.format("Unknown health check type: %s", s));
        }
    }

    @JsonValue
    public String getValue() {
        return this.value;
    }

    @Override
    public String toString() {
        return getValue();
    }

}

==> cloudfoundry-client-5.12.2.RELEASE-sources.jar: org/cloudfoundry/client/v3/processes/HealthCheckType.java <==
/*
 * Copyright 2013-2021 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.cloudfoundry.client.v3.processes;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;

/**
 * The type of a {@link HealthCheck}
 */
public enum HealthCheckType {

    /**
     * An http health check
     */
    HTTP("http"),

    /**
     * No health check (deprecated, backwards compatibility only)
     */
    @Deprecated
    NONE("none"),

    /**
     * A port health check
     */
    PORT("port"),

    /**
     * A process health check
     */
    PROCESS("process");

    private final String value;

    HealthCheckType(String value) {
        this.value = value;
    }

    @JsonCreator
    public static HealthCheckType from(String s) {
        switch (s.toLowerCase()) {
            case "http":
                return HTTP;
            case "none":
                return NONE;
            case "port":
                return PORT;
            case "process":
                return PROCESS;
            default:
                throw new IllegalArgumentException(
                        String.format("Unknown health check type: %s", s));
        }
    }

    @JsonValue
    public String getValue() {
        return this.value;
    }

    @Override
    public String toString() {
        return getValue();
    }
}
